==> percona-mysql-shell_8.0.34-1-1.tar.xz: mysql-shell-8.0.34/unittest/scripts/js_devapi/validation/dba_super_read_only_handling.js <==
//@ Initialization
||

//@<OUT> Configures the instance, answers 'yes' on the read only prompt
Configuring local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB cluster...
NOTE: Instance detected as a sandbox.
Please note that sandbox instances are only suitable for deploying test clusters for use within the same host.

This instance reports its own address as <<<hostname>>>:<<<__mysql_sandbox_port1>>>
Assuming full account name 'testUser'@'%' for testUser

?{VER(>=8.0.23)}
applierWorkerThreads will be set to the default value of 4.

?{}
The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' is valid to be used in an InnoDB cluster.

The MySQL instance at 'localhost:<<<__mysql_sandbox_port1>>>' currently has the super_read_only system
variable set to protect it from inadvertent updates from applications.
You must first unset it to be able to perform any changes to this instance.
For more information see:
https://dev.mysql.com/doc/refman/en/server-system-variables.html#sysvar_super_read_only.

Do you want to disable super_read_only and continue? [y/N]: Disabled super_read_only on the instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>'
Creating user testUser@%.
Account testUser@% was successfully created.

Enabling super_read_only on the instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>'

//@<OUT> Configures the instance, read only set, no prompt
Configuring local MySQL instance listening at port <<<__mysql_sandbox_port2>>> for use in an InnoDB cluster...
NOTE: Instance detected as a sandbox.
Please note that sandbox instances are only suitable for deploying test clusters for use within the same host.

This instance reports its own address as <<<hostname>>>:<<<__mysql_sandbox_port2>>>
Assuming full account name 'testUser'@'%' for testUser

?{VER(>=8.0.23)}
applierWorkerThreads will be set to the default value of 4.

?{}
The instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>' is valid to be used in an InnoDB cluster.
Disabled super_read_only on the instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>'
Creating user testUser@%.
Account testUser@% was successfully created.

Enabling super_read_only on the instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>'

//@<OUT> Configures the instance, no prompt
Configuring local MySQL instance listening at port <<<__mysql_sandbox_port3>>> for use in an InnoDB cluster...
NOTE: Instance detected as a sandbox.
Please note that sandbox instances are only suitable for deploying test clusters for use within the same host.

This instance reports its own address as <<<hostname>>>:<<<__mysql_sandbox_port3>>>
Assuming full account name 'testUser'@'%' for testUser

?{VER(>=8.0.23)}
applierWorkerThreads will be set to the default value of 4.

?{}
The instance '<<<hostname>>>:<<<__mysql_sandbox_port3>>>' is valid to be used in an InnoDB cluster.

Creating user testUser@%.
Account testUser@% was successfully created.

//@ Creates Cluster succeeds (should auto-clear)
|Disabling super_read_only mode on instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>'.|

//@ Adds a read only instance
|The instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>' was successfully added to the cluster.|

//@ Adds other instance
|The instance '<<<hostname>>>:<<<__mysql_sandbox_port3>>>' was successfully added to the cluster.|

//@ Rejoins an instance
|The instance '<<<hostname>>>:<<<__mysql_sandbox_port3>>>' was successfully rejoined to the cluster.|

//@ persist GR configuration settings for 5.7 servers {VER(<8.0.11)}
||

//@ Reset gr_start_on_boot on all instances
||

//@# Reboot the cluster
|Restoring the Cluster 'sample' from complete outage...|

|The Cluster was successfully rebooted.|

//@ Cleanup
||

==> percona-mysql-shell_8.3.0-1-1.tar.xz: mysql-shell-8.3.0/unittest/scripts/js_devapi/validation/dba_super_read_only_handling.js <==
//@ Initialization
||

//@<OUT> Configures the instance, answers 'yes' on the read only prompt
Configuring local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB Cluster...
NOTE: Instance detected as a sandbox.
Please note that sandbox instances are only suitable for deploying test clusters for use within the same host.

This instance reports its own address as <<<hostname>>>:<<<__mysql_sandbox_port1>>>
Assuming full account name 'testUser'@'%' for testUser
?{VER(>=8.0.23)}

applierWorkerThreads will be set to the default value of 4.
?{}
Disabled super_read_only on the instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>'

Creating user testUser@%.
Account testUser@% was successfully created.

Enabling super_read_only on the instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>'

The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' is valid for InnoDB Cluster usage.

//@<OUT> Configures the instance, read only set, no prompt
Configuring local MySQL instance listening at port <<<__mysql_sandbox_port2>>> for use in an InnoDB Cluster...
NOTE: Instance detected as a sandbox.
Please note that sandbox instances are only suitable for deploying test clusters for use within the same host.

This instance reports its own address as <<<hostname>>>:<<<__mysql_sandbox_port2>>>
Assuming full account name 'testUser'@'%' for testUser
?{VER(>=8.0.23)}

applierWorkerThreads will be set to the default value of 4.
?{}
Disabled super_read_only on the instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>'

Creating user testUser@%.
Account testUser@% was successfully created.

Enabling super_read_only on the instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>'

The instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>' is valid for InnoDB Cluster usage.

//@<OUT> Configures the instance, no prompt
Configuring local MySQL instance listening at port <<<__mysql_sandbox_port3>>> for use in an InnoDB Cluster...
NOTE: Instance detected as a sandbox.
Please note that sandbox instances are only suitable for deploying test clusters for use within the same host.

This instance reports its own address as <<<hostname>>>:<<<__mysql_sandbox_port3>>>
Assuming full account name 'testUser'@'%' for testUser
?{VER(>=8.0.23)}

applierWorkerThreads will be set to the default value of 4.
?{}

Creating user testUser@%.
Account testUser@% was successfully created.


The instance '<<<hostname>>>:<<<__mysql_sandbox_port3>>>' is valid for InnoDB Cluster usage.

//@ Creates Cluster succeeds (should auto-clear)
|Disabling super_read_only mode on instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>'.|

//@ Adds a read only instance
|The instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>' was successfully added to the cluster.|

//@ Adds other instance
|The instance '<<<hostname>>>:<<<__mysql_sandbox_port3>>>' was successfully added to the cluster.|

//@ Rejoins an instance
|The instance '<<<hostname>>>:<<<__mysql_sandbox_port3>>>' was successfully rejoined to the cluster.|

//@ persist GR configuration settings for 5.7 servers {VER(<8.0.11)}
||

//@ Reset gr_start_on_boot on all instances
||

//@# Reboot the cluster
|Restoring the Cluster 'sample' from complete outage...|

|The Cluster was successfully rebooted.|

//@ Cleanup
||
